%define orig_name PianoBooster

Name:           pianobooster
Version:        1.0.0
Release:        %mkrel 5
Summary:        A MIDI file player that teaches you how to play the piano
Group:          Sound/Midi
License:        GPLv3+
Url:            https://github.com/captnfab/PianoBooster
Source0:        https://github.com/captnfab/PianoBooster/archive/v%{version}/%{orig_name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(rtmidi)
BuildRequires:  hicolor-icon-theme

Requires:       fonts-ttf-dejavu
Requires:       unzip
Requires:       hicolor-icon-theme

Recommends:     qttranslations5

%description
A MIDI file player/game that displays the musical notes AND teaches you how
to play the piano.

PianoBooster is a fun way of playing along with a musical accompaniment and
at the same time learning the basics of reading musical notation.
The difference between playing along to a CD or a standard MIDI file
is that PianoBooster listens and reacts to what you are playing on a
MIDI keyboard.

To run Piano Booster you need a MIDI Piano Keyboard and a MIDI interface
for the PC. If you don't have a MIDI keyboard you can still try out
PianoBooster, using the PC keyboard ('x' is middle C), but a MIDI piano
is really recommended.

%files
%doc README.md Changelog.txt doc/faq.md
%license license.txt
%{_gamesbindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%dir %{_datadir}/games/%{name}
%dir %{_datadir}/games/%{name}/music
%dir %{_datadir}/games/%{name}/translations
%{_datadir}/games/%{name}/music/*.zip
%{_datadir}/games/%{name}/translations/%{name}*.qm
#{_datadir}/games/%%{name}/translations/music*.qm
%{_datadir}/games/%{name}/translations/*.json
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------------
%if 0
# Changed USE_FLUIDSYNTH to EXPERIMENTAL_USE_FLUIDSYNTH as this option is not working yet

%package        fluidsynth
Summary:        Wrapper to launch PianoBooster with FluidSynth as MIDI sequencer
Group:          Sound/Midi
BuildRequires:  pkgconfig(fluidsynth)
Requires:       %{name} >= %{version}-%{release}
Requires:       fluidsynth
Requires:       fluid-soundfont-gm
Requires:       fluid-soundfont-gs
Requires:       libnotify

%description    fluidsynth
This package contains a wrapper script to launch PianoBooster together with
FluidSynth in ALSA server mode. This makes it possible to play the MIDI files
even without a plugged-in MIDI keyboard.

%files          fluidsynth
%{_gamesbindir}/%{name}-fluidsynth
%{_datadir}/applications/%{name}-fluidsynth.desktop
%endif
#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{orig_name}-%{version}

%build
%cmake \
       -DCMAKE_INSTALL_BINDIR=%{_gamesbindir} \
       -DUSE_SYSTEM_FONT=ON \
       -DNO_DOCS=ON \
       -DNO_LICENSE=ON \
       -DNO_CHANGELOG=ON \
       -DNO_LANGS=OFF \
       -DUSE_BUNDLED_RTMIDI=OFF \
       -DWITH_MAN=ON
%cmake_build

%install
%cmake_install


%changelog
* Mon Jan 30 2023 daviddavid <daviddavid> 1.0.0-5.mga9
+ Revision: 1937070
- rebuild for new rtmidi 5.0.0

* Sun Apr 03 2022 umeabot <umeabot> 1.0.0-4.mga9
+ Revision: 1842586
- Mageia 9 Mass Rebuild

* Thu Aug 05 2021 luigiwalser <luigiwalser> 1.0.0-3.mga9
+ Revision: 1739419
- rebuild for fluidsynth

* Thu Dec 17 2020 umeabot <umeabot> 1.0.0-2.mga8
+ Revision: 1659381
- Rebuild for new Qt5

* Tue Dec 15 2020 daviddavid <daviddavid> 1.0.0-1.mga8
+ Revision: 1657861
- new version: 1.0.0

* Mon Feb 24 2020 daviddavid <daviddavid> 0.7.2-1.mga8
+ Revision: 1549908
- new version: 0.7.2

* Sun Feb 16 2020 umeabot <umeabot> 0.7.0-2.mga8
+ Revision: 1530585
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Sep 03 2019 alexl <alexl> 0.7.0-1.mga8
+ Revision: 1436574
- version 0.7.0
- use spec file from upstream

* Mon Apr 01 2019 umeabot <umeabot> 0.7.0-1.alpha.20190313.7.mga7
+ Revision: 1383923
- Qt5 Rebuild

* Thu Mar 14 2019 alexl <alexl> 0.7.0-1.alpha.20190313.6.mga7
+ Revision: 1375925
- the latest git snapshot

* Mon Mar 04 2019 alexl <alexl> 0.7.0-1.alpha.20190304.5.mga7
+ Revision: 1371259
- the latest git snapshot
- del upstreamed patches
- add requires on unzip
- install all languages
- fix permisions on desktop file

* Tue Feb 26 2019 alexl <alexl> 0.7.0-1.alpha.20190226.4.mga7
+ Revision: 1370303
- the latest git snapshot
- del upstreamed stuff

* Thu Feb 21 2019 alexl <alexl> 0.7.0-1.alpha.20190125.3.mga7
+ Revision: 1369023
- fix localization for instruments

* Thu Feb 21 2019 alexl <alexl> 0.7.0-1.alpha.20190125.2.mga7
+ Revision: 1369021
- fix drawing with qt5 (thanks to admsasha for patch)
- fix timidity wrapper script

* Thu Jan 31 2019 alexl <alexl> 0.7.0-1.alpha.20190125.1.mga7
+ Revision: 1362045
- fix font path and add requires on font
- update desktop files
- do not install docs twice
- enable qt translations

* Fri Jan 25 2019 akien <akien> 0.7.0-0.alpha.20190125.1.mga7
+ Revision: 1360671
- Version 0.7.0-alpha, snapshot from 20190125

* Sun Sep 23 2018 umeabot <umeabot> 0.6.4b-6.mga7
+ Revision: 1300259
- Mageia 7 Mass Rebuild

* Fri Feb 05 2016 umeabot <umeabot> 0.6.4b-5.mga6
+ Revision: 937646
- Mageia 6 Mass Rebuild

* Fri Feb 05 2016 umeabot <umeabot> 0.6.4b-4.mga6
+ Revision: 937193
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.6.4b-3.mga5
+ Revision: 746593
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.6.4b-2.mga5
+ Revision: 687573
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Fri Apr 25 2014 akien <akien> 0.6.4b-1.mga5
+ Revision: 618009
- Adapt wrapper script to kill the timidity server when pianobooster is closed
- Add -timidity package with a wrapper script to start TiMidity sequencer
- Rewrite spec file
- Revert to latest stable release 0.6.4b
+ matteo <matteo>
- added explicit linking to gl and pthread
- new version
- cmake added as build requirement
- pianobooster.spec upgrade due to sources upgrade
- imported package pianobooster

